package services

import (
	"errors"
	"gopkg.in/gomail.v2"
	"hongze/hongze_yb_en_api/models/msg_code"
	"hongze/hongze_yb_en_api/utils"
	"strings"
	"time"
)


// SendEmailCode 发送邮件
func SendEmailCode(name,email string) (err error, errMsg string) {
	if email == "" {
		err = errors.New("请输入邮箱地址")
		return
	}
	if !utils.ValidateEmailFormatat(email) {
		err = errors.New("邮箱格式错误，请重新输入")
		return
	}
	msgCode := utils.GetRandDigit(4)
	content := "Hi "+ name +"：</br>Please enter this verification code on the registration page so we can make sure it's you：</br><p>" + msgCode + "</p>This code will expire in 15 minutes.</br>" +
		"If you didn't initiate this request, or need help with your registration, please let us know at: stephanie@hzinsights.com </br>Horizon Research Team"
	title := "Your Email Verification Code"
	//发送邮件
	result, err := SendEmailByHz(title, content, email)

	if result {
		item := &msg_code.MsgCode{
			Mobile:          email,
			Code:            msgCode,
			ExpiredIn:       time.Now().Add(15 * time.Minute).Unix(),
			Enabled:         1,
			CreatedTime:     time.Time{},
			LastUpdatedTime: time.Time{},
		}
		err = item.Create()
	} else {
		err = errors.New("发送失败")
	}

	return
}

//发送邮件
func SendEmailByHz(title, content string, touser string) (result bool, err error) {
	var arr []string
	sub := strings.Index(touser, ";")
	if sub >= 0 {
		spArr := strings.Split(touser, ";")
		for _, v := range spArr {
			arr = append(arr, v)
		}
	} else {
		arr = append(arr, touser)
	}
	m := gomail.NewMessage()
	m.SetHeader("From", "public@hzinsights.com")
	m.SetHeader("To", arr...)
	m.SetHeader("Subject", title)
	m.SetBody("text/html", content)
	d := gomail.NewDialer("smtp.mxhichina.com", 465, "public@hzinsights.com", "Hzinsights2018")
	if err := d.DialAndSend(m); err != nil {
		result = false
		return result, err
	}
	result = true
	return
}
